package com.ruoyi.ems.service;

import com.ruoyi.ems.domain.CaMeterD;
import java.util.List;

/**
 * 碳计量日Service接口
 */
public interface ICaMeterDService {

    CaMeterD selectCaMeterDById(Long id);

    /** 根据时间类型查询列表（分页） */
    List<CaMeterD> selectCaMeterDListByTimeType(CaMeterD caMeterD, String timeType);

    /** 根据时间类型查询汇总（统计用） */
    List<CaMeterD> selectSumCaMeterDListByTimeType(CaMeterD caMeterD, String timeType);

    List<CaMeterD> selectAvgCaMeterDList(CaMeterD caMeterD);

    int insertCaMeterD(CaMeterD caMeterD);

    int updateCaMeterD(CaMeterD caMeterD);

    int deleteCaMeterDByIds(Long[] ids);
}